#
# spec file for package partitionmanager
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define kf6_version 6.6.0
%define qt6_version 6.6.0

%bcond_without released
Name:           partitionmanager
Version:        24.12.1
Release:        1.1
Summary:        Easily manage disks, partitions and file systems on your KDE Desktop
License:        GPL-3.0-or-later
URL:            https://apps.kde.org/partitionmanager
Source0:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz.sig
Source2:        applications.keyring
%endif
BuildRequires:  kf6-extra-cmake-modules >= %{kf6_version}
BuildRequires:  cmake(KF6Config) >= %{kf6_version}
BuildRequires:  cmake(KF6ConfigWidgets) >= %{kf6_version}
BuildRequires:  cmake(KF6CoreAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6Crash) >= %{kf6_version}
BuildRequires:  cmake(KF6DBusAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6DocTools) >= %{kf6_version}
BuildRequires:  cmake(KF6I18n) >= %{kf6_version}
BuildRequires:  cmake(KF6JobWidgets) >= %{kf6_version}
BuildRequires:  cmake(KF6KIO) >= %{kf6_version}
BuildRequires:  cmake(KF6WidgetsAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6WindowSystem) >= %{kf6_version}
BuildRequires:  cmake(KF6XmlGui) >= %{kf6_version}
BuildRequires:  cmake(KPMcore)
BuildRequires:  cmake(PolkitQt6-1)
BuildRequires:  cmake(Qt6Core) >= %{qt6_version}
BuildRequires:  cmake(Qt6Gui) >= %{qt6_version}
BuildRequires:  cmake(Qt6Widgets) >= %{qt6_version}
Obsoletes:      partitionmanager5 < %{version}
Provides:       partitionmanager5 = %{version}

%description
This software allows you to manage your disks, partitions and
file systems: Create, resize, delete, copy, backup and restore
partitions with a large number of supported file systems (ext2/3,
reiserfs, NTFS, FAT32 and more). It makes use of external
programs to get its job done, so you might have to install
additional software (preferably packages from your distribution)
to make use of all features and get full support for all file
systems.

%lang_package

%prep
%autosetup -p1

%build
%cmake_kf6

%kf6_build

%install
%kf6_install

%find_lang partitionmanager --with-html

%files
%doc README.md
%license LICENSES/*
%doc %lang(en) %{_kf6_htmldir}/en/partitionmanager/
%{_kf6_applicationsdir}/org.kde.partitionmanager.desktop
%{_kf6_appstreamdir}/org.kde.partitionmanager.appdata.xml
%{_kf6_bindir}/partitionmanager
%{_kf6_configkcfgdir}/partitionmanager.kcfg
%{_kf6_iconsdir}/hicolor/*/apps/partitionmanager.svg
%dir %{_kf6_sharedir}/solid
%dir %{_kf6_sharedir}/solid/actions
%{_kf6_sharedir}/solid/actions/open_in_partitionmanager.desktop

%files lang -f partitionmanager.lang
%exclude %{_kf6_htmldir}/en/partitionmanager/

%changelog
* Tue Jan  7 2025 Christophe Marin <christophe@krop.fr>
- Update to 24.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.1/
- No code change since 24.12.0
* Sun Dec  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.0/
- No code change since 24.11.90
* Mon Dec  2 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.11.90
  * New feature release
- No code change since 24.11.80
* Sat Nov 16 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.11.80
  * New feature release
- Changes since 24.08.3:
  * Don't include quiet packages in feature_summary
  * Additional mount point options should come after box options from GUI. (kde#495440)
  * Improve tab order in partition create dialog. (kde#494557)
  * Use the correct QT6 screenshot
  * Remove virtual keyword when we use override
* Tue Nov  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.3/
- No code change since 24.08.2
* Tue Oct  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.2/
- No code change since 24.08.1
* Tue Sep 10 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.1/
- No code change since 24.08.0
* Mon Aug 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.0/
- Changes since 24.05.2:
  * Fix crash when closing main window while prompted for root password. (kde#451572)
  * Hide LUKS2 checkbox in resize dialog.
  * Remove support for CHS alignment.
  * Fixed crash caused by clicking remove mount point button (kde#432103)
* Tue Jul  2 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.2/
- Changes since 24.05.1:
  * Fixed crash caused by clicking remove mount point button (kde#432103)
* Wed Jun 12 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.1/
- No code change since 24.05.0
* Sun May 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.0/
- No code change since 24.04.80
* Fri May  3 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.04.80
  * New feature release
- Changes since 24.02.2:
  * Port deprecated methods
  * Add missing include moc
  * Use QDir::canonicalPath() for /home
  * Enable nofail by default for / and /home (kde#476054)
  * Add an fstab nofail mount option (kde#472431)
  * Hide partition type on GPT disks
  * Add LUKS2 option when creating LUKS partition
  * Initial support for bcachefs.
  * Use StartupNotify now instead of X-KDE-StartupNotify
* Tue Apr  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.02.2/
- No code change since 24.02.1
* Tue Mar 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.02.1/
- No code change since 24.02.0
* Fri Feb 23 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.0
  * New feature release
- No code change since 24.01.95
* Fri Feb  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.01.95
  * https://kde.org/announcements/megarelease/6/rc2/
* Wed Jan 31 2024 Christophe Marin <christophe@krop.fr>
- Switch to the latest GCC version available in Leap for packages
  that can't build with the default compiler
* Tue Dec  5 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.4/
- No code change since 23.08.3
* Tue Nov  7 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.3/
- No code change since 23.08.2
* Tue Oct 10 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.2/
- No code change since 23.08.1
* Tue Sep 12 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.1/
- No code change since 23.08.0
* Sun Aug 20 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.0/
- No code change since 23.07.90
* Mon Aug 14 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.90
  * New feature release
- Changes since 23.07.80:
  * Fix dep5 license file syntax
* Tue Aug  1 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.80
  * New feature release
- Changes since 23.04.3:
  * Add explicit moc includes to sources for moc-covered headers
  * Add copyright info to the new partitionmanager icon.
  * Adopt new Breeze icon
  * Remove unnecessary kpmcore prefix for KPMCore custom widgets
  * Rename Partition Label to Partition Name
* Tue Jul  4 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.3/
- No code change since 23.04.2
* Tue Jun  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.2/
- No code change since 23.04.1
* Tue May  9 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.1/
- No code change since 23.04.0
* Sat Apr 15 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.0/
* Fri Mar 31 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.90
  * New feature release
* Fri Mar 17 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.80
  * New feature release
* Tue Feb 28 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.3/
* Tue Jan 31 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.2/
* Tue Jan  3 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.1/
* Fri Dec  2 2022 Christophe Marin <christophe@krop.fr>
- Update to 22.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.0/
* Sat Nov 26 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.11.90
  * New feature release
* Sat Nov 12 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.11.80
  * New feature release
* Tue Nov  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.3/
* Tue Oct 11 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.2/
* Tue Sep  6 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.1/
* Sun Aug 14 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.0/
* Fri Aug  5 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.07.90
  * New feature release
* Sat Jul 16 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.07.80
  * New feature release
* Tue Jul  5 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.3/
* Wed Jun  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.2/
* Tue May 10 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.1/
* Mon Apr 18 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.0/
* Fri Apr  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.03.90
  * New feature release
* Wed Mar 23 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.03.80
  * New feature release
- Too many changes since 21.12.3, only listing bugfixes:
  * Make refreshing devices more intuitive in the GUI. (kde#450355)
  * Add an "Open in Partition Manager" solid Action (kde#446897)
  * Accept devices starting with /dev (kde#446899)
  * Improve tab focus order in create partition dialog. (kde#444698)
  * Select device using a command line option (kde#43485)
* Fri Mar 11 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update license to GPL-3.0-or-later.
* Wed Mar  2 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.3/
- No code change since 21.12.2
* Sat Feb  5 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.2/
- No code change since 21.12.1
* Thu Jan 13 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.1/
- Changes since 21.08.3:
  * Bump minimal cmake version to 3.16
* Sat Nov 13 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.3/
- No code change since 21.08.1
* Mon Sep  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.1
- No code change since 21.08.0
* Fri Aug  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.0
- Changes since 21.04.2:
  * Switch default file system to Btrfs (kde#438376)
* Fri Jun 25 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04.2
- No code change since 21.04.1
* Wed May 19 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04.1
- Changes since 21.04.0:
  * Fix appstream link
* Tue Apr 20 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04
* Tue Oct 27 2020 wbauer@tmo.at
- Update to 4.2.0
  * KAuth helper replaced with pure PolkitQt1 helper
  * KDE Partition Manager (including KPMcore library) is now fully
    REUSE 3.0 compliant
  * Support for partitions with unknown file system
  * Fixed and improved mount point and /etc/fstab handling
  * Fixed a crash that was present for a long time but hard to
    reproduce reliably
  * KPMcore gained support for GPT partition attributes (It is not
    yet wired in KDE Partition Manager)
  * KPMcore has more support for setting GPT partition label and
    UUID (Again, not yet wired in KDE Partition Manager)
  * Port away from various deprecated Qt/KDE methods
  * Workaround bad JSON output from sfdisk (will be fixed in
    util-linux 2.37).
  * Import partition flags when importing partition table
  * Apply colour scheme to secondary (MBR logical) partitions
* Mon Feb 10 2020 wbauer@tmo.at
- Update to 4.1.0
  * Support for Minix file system
* Fri May 24 2019 wbauer@tmo.at
- Update to 4.0.0
  * Ported to KAuth to let the GUI run as unprivileged user
  * KPMcore backend was ported away from libparted to sfdisk (part
    of util-linux)
  * Ported S.M.A.R.T. code away from unmaintained libatasmart to
    smartmontools
  * Better support for LUKS2
  * Detection support for Apple's APFS filesystem and Microsoft's
    Bitlocker
  * Many of the KPMcore classes now use d-pointers, which in the
    future releases will help us to maintain binary compatibility
    (ABI) a bit better
  * Use more modern C++ features
  * Some bugfixes, in particular related to LVM
* Tue Oct 16 2018 Fabian Vogt <fabian@ritter-vogt.de>
- Use %%license
- Move en doc file from -lang into the main package
* Mon Jan  8 2018 wbauer@tmo.at
- Update to 3.3.1
  * Fix one crash when resizing LVM logical volumes
* Fri Dec 15 2017 wbauer@tmo.at
- Update to 3.3.0
  * some improvements for Btrfs, F2FS, NTFS file systems
  * first bits of new LUKS2 on-disk format support, now KDE
    Partition Manager can display LUKS2 labels
* Sun Oct  8 2017 wbauer@tmo.at
- Update to 3.2.1
  * Fix a broken QRegularExpression in LVM VG name validator.
* Sun Oct  1 2017 wbauer@tmo.at
- Update to 3.2.0
  * Added support for UDF file system (this change requires
    util-linux 2.30). While adding support for UDF, the following
    general improvements were made:
    + KPM now supports setting label for file systems where it can
    only be done during initial formating (e.g. nilfs2 or udf)
    + File system label widget (QLineEdit) now validates its input
    for certain file systems (at the moment only FAT and UDF),
    not just maximum label length.
  * Detection support for ISO9660 file system
* Wed Sep  6 2017 wbauer@tmo.at
- Update to 3.1.2
  * Add back translated docs that were missing in 3.1.1
- Update to 3.1.1
  * Fix a crash when clicking cancel in ApplyProgressDialog.
    (kde#384348)
* Mon Jun 19 2017 wbauer@tmo.at
- Update to 3.1.0
  * Workaround for a change/bug (see kde#380974) in KNotifications
    5.33 that in some cases caused KMessageBoxes to hang for a few
    seconds.
- Adjust build requirements, Qt 5.7.0 and Frameworks 5.31.0 are
  needed now
- Use %%kf5_find_htmldocs to generate the documentation file list
* Sat Jan  7 2017 wbauer@tmo.at
- Update to 3.0.1
* Mon Dec 19 2016 fabian@ritter-vogt.de
- Update to 3.0.0
- Sync with KDE:Unstable:Extra
- Update license to GPL-3.0
* Fri Aug 26 2016 wbauer@tmo.at
- Update to 2.2.1
- Adjust build requirements
- Add update-appstream-path-to-use-ECM-variable.patch to install
  the appstream data to the right place and use the
  %%{kf5_appstreamdir} macro for the file list
* Sun Jun 19 2016 jacobwinski@gmail.com
- Update to 2.2.0.
- Update kpmcore version requirement in spec file.
* Sun Apr  3 2016 hrvoje.senjan@gmail.com
- Update to 2.1.0
* Mon Jan 18 2016 tittiatcoke@gmail.com
- Update to 2.0.0
  * Split out the kpmcore library from the main package
* Fri May  1 2015 asterios.dramis@gmail.com
- Added new build requirement kwindowsystem-devel.
- Removed unneeded build requirement fdupes.
* Mon Apr  6 2015 hrvoje.senjan@gmail.com
- Update to 1.2.1:
  * Port to KDE Frameworks is complete
- Drop the udisks2 cmake option, no longer needed
* Thu Jul 10 2014 hrvoje.senjan@gmail.com
- Update to 1.1.0
  * Most important changes in this release are support for Btrfs
    file system and GPT partition table. This release also adds
    support for exFAT, NILFS 2 and very basic support for ZFS,
    encrypted LUKS containers and LVM2 physical volumes. There
    are some nice GUI improvements as well, partition widget
    design was improved by Hugo Pereira Da Costa.
- Enable UDisks2 backend
- Minor spec cleanup
* Tue Nov  5 2013 dmitry_r@opensuse.org
- Add partitionmanager-lang as recommended dependence
* Mon Oct  4 2010 bitshuffler@opensuse.org
- Updated to 1.0.3
  * Make sure available and used capacity are not printed in a partition's
    properties dialog if they are not known
  * Make sure fsck.msdos does not want to modify a file system when it is being
    called to read the file system usage
  * Warn the user when trying to overwrite an existing partition with another or
    an image file
  * Clear the clipboard if undoing an operation deleted the partition that was in it
  * Keep the current UUID when resizing a swap partition
  * Fix the build by explicitly linking the partition manager executable against
    the KDE libs it uses
  * Do not allow pasting a source partition on a bigger target partition when the
    source partition's file system cannot be grown to fill the target partition
* Sun Jul 25 2010 bitshuffler@opensuse.org
- Updated to 1.0.2
  * Copy a file system's UUID to the copied file system when creating a file
    system from another one.
  * Implement a workaround for a libparted bug that makes it sometimes fail to
    commit changes to the OS in versions earlier than 2.2.
  * Update the partition's file system and re-check for constraints if the
    partition's role is changed in the "Create New Partition" dialog. This fixes
    a bug where the user was not able to grow an extended partition if he'd
    previously selected a file system that cannot grow beyond a certain size.
  * Always use the correct icons in modified ok/cancel buttons in dialogs and
    message boxes
  * Fix a crash when operations to create, resize and delete an extended
    partitions where incorrectly merged into one (bug 232092)
* Sun Jan 10 2010 rwooninck@opensuse.org
- Updated to 1.0.1
  - Fix a bug that made it impossible to activate or deactivate a
    swap file system.
  - Correctly handle linux swap even with newer parted versions.
  - Ask for an administrator's password on startup so that non-KDE
    users can run the application from their launcher.
  - Use the "blkid" command as an alternative to "vol_id" if the
    latter is unavailable.
  - Do not crash when using the Oxygen style under KDE SC 4.4.
  - Do not crash when the user clicks in the partition widget with
    newer g++ versions.
  - Sort devices by name after scanning.
  - Don't disable updates for the partition widget while applying
    operations. This leads to corrupted graphics unter Qt4.6.
  - Work around a LibParted segmentation fault when the Linux Device
    Mapper is used and /dev/mapper has non-existing entries.
  - The above also works around a LibParted problem when the BIOS has
    a floppy drive configured but none is actually present.
  - Set item height in the partition and devices lists to 32 pixel
    to make them look less condensed.
* Thu Oct  8 2009 bitshuffler@opensuse.org
- Updated to 1.0.0
  - Many translations heavily improved.
  - Correctly handle ext4 file systems even with patched parted 1.8.8 (and hopefully 1.8.9 too). Patch by Fatih Asici. (bug #195243)
  - Clear the partition flags for a copied partition in the preview. (bug #202346)
  - Write the new start sector to the partition's boot sector if an NTFS file system was moved or copied. (bug #202329)
* Sun Jun  7 2009 tittiatcoke@gmail.com
- Moved to KDE:KDE4:Community
* Sun Jun  7 2009 tittiatcoke@gmail.com
- moved to KDE:KDE4:Community
  + version 1.0.0beta3
  - Set the default file system in the New-Partition-dialog, don't just rely on it being the first one in the list.
  - Sort items in file system combo boxes case-insensitively.
  - Fix a bug where the total free space available could get smaller and smaller when moving an existing partition in a dialog.
  - Fix a bug that the progress information wasn't set as window title for the top level application window.
  - Speed up copying file systems (and thus moving, resizing and copying).
  - Add some basic timing output to the detailed report for copying file systems.
  - Find a file system's mount point even if it is identified by label in fstab.
  - Add support for reading file system labels from FAT16 and FAT32.
  - Fix a bug where the volume label for a linuxswap file system was lost when resizing it.
  - Make sure all interesting information shown in labels anywhere in the application is user-selectable with the mouse.
  - Display the UUID for most file systems that support it.
  - Always show the current file system in the partition properties dialog's file system combo box, even if it cannot be created, is too big or too small.
* Wed Jun  3 2009 vl@fidra.de
- new upstream version
* Wed Apr 29 2009 vl@fidra.de
- new upstream version
* Tue Jan 13 2009 vl@fidra.de
- modified for opensuse build service
* Mon Jan 12 2009 toni@links2linux.de
- update to 1.0.0beta1
* Tue Sep 23 2008 toni@links2linux.de
- update to 1.0.0alpha2
* Thu Sep 18 2008 toni@links2linux.de
- initial build for 1.0.0-Alpha1
